.. _history:

=======
History
=======

0.0.10 (2018-08-09)
------------------

* 1st version for SciServer image
* PV bugs fixed
* Doc OK

0.0.9 (2018-08-07)
------------------

* OceanSpy skeleton: start collaborating with Haine group.
